import { Action } from '@ngrx/store';
export interface SetSelectedEntityAction<T> extends Action {
    payload: string;
}
export interface LoadAction<T> extends Action {
    entityName: string;
}
export interface LoadSuccessAction<T> extends Action {
    entityName: string;
    payload: T[];
}
export interface LoadErrorAction<T> extends Action {
    entityName: string;
    payload: any;
}
export interface AddAction<T> extends Action {
    entityName: string;
    payload: T;
}
export interface AddSuccessAction<T> extends Action {
    entityName: string;
    payload: T;
}
export interface AddErrorAction<T> extends Action {
    entityName: string;
    payload: any;
}
export interface EditAction<T> extends Action {
    entityName: string;
    payload: T;
}
export interface EditSuccessAction<T> extends Action {
    entityName: string;
    payload: T;
}
export interface EditErrorAction<T> extends Action {
    entityName: string;
    payload: any;
}
export interface DeleteAction<T> extends Action {
    entityName: string;
    payload: T;
}
export interface DeleteSuccessAction<T> extends Action {
    entityName: string;
    payload: T;
}
export interface DeleteErrorAction<T> extends Action {
    entityName: string;
    payload: any;
}
export declare type Actions<T> = SetSelectedEntityAction<T> | LoadAction<T> | LoadSuccessAction<T> | LoadErrorAction<T> | AddAction<T> | AddSuccessAction<T> | AddErrorAction<T> | EditAction<T> | EditSuccessAction<T> | EditErrorAction<T> | DeleteAction<T> | DeleteSuccessAction<T> | DeleteErrorAction<T>;
export interface ActionCollection<T> {
    SELECTED_ENTITY: string;
    LOAD: string;
    LOAD_SUCCESS: string;
    LOAD_ERROR: string;
    ADD: string;
    ADD_SUCCESS: string;
    ADD_ERROR: string;
    EDIT: string;
    EDIT_ERROR: string;
    EDIT_SUCCESS: string;
    DELETE: string;
    DELETE_ERROR: string;
    DELETE_SUCCESS: string;
    SELECT: string;
    getSetSelectedEntityAction(payload: string): SetSelectedEntityAction<T>;
    getLoadAction(): LoadAction<T>;
    getLoadSuccessAction(payload: T[]): LoadSuccessAction<T>;
    getLoadErrorAction(payload: any): LoadErrorAction<T>;
    getAddAction(payload: T): AddAction<T>;
    getAddSuccessAction(payload: T): AddSuccessAction<T>;
    getAddErrorAction(payload: any): AddErrorAction<T>;
    getEditAction(payload: T): EditAction<T>;
    getEditSuccessAction(payload: T): EditSuccessAction<T>;
    getEditErrorAction(payload: any): EditErrorAction<T>;
    getDeleteAction(payload: T): DeleteAction<T>;
    getDeleteSuccessAction(payload: T): DeleteSuccessAction<T>;
    getDeleteErrorAction(payload: T): DeleteErrorAction<T>;
}
export declare function getEntityAction<T>(entityName: string): ActionCollection<T>;
