import { getEntityAction } from './actions';
import { Injectable } from '@angular/core';
import { Actions, Effect } from '@ngrx/effects';
import 'rxjs/add/operator/switchMap';
import 'rxjs/add/operator/mergeMap';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/filter';
import 'rxjs/add/observable/empty';
import 'rxjs/add/observable/of';
import 'rxjs/add/operator/take';
import 'rxjs/add/operator/do';
import 'rxjs/add/operator/catch';
import { EntityService, } from '.';
import { Observable } from 'rxjs/Observable';
function extractEntityName(reg, value) {
    var results = reg.exec(value);
    if (results === null || results.length < 2) {
        return null;
    }
    return results[1];
}
var EntityEffects = (function () {
    function EntityEffects(_actions$, _entityService) {
        var _this = this;
        this._actions$ = _actions$;
        this._entityService = _entityService;
        this.loadEntities = this._actions$
            .do(function (a) { return console.log('all action ', a); })
            .filter(function (action) { return action.type.match(/^.*\/load$/) !== null; })
            .do(function (a) { return console.log('action matched', a); })
            .flatMap(function (action) {
            var entityName = extractEntityName(/^(.*)\/load$/, action.type);
            if (entityName !== null) {
                return _this._entityService
                    .getEntities(entityName.toLowerCase())
                    .map(function (entities) { return getEntityAction(entityName).getLoadSuccessAction(entities); })
                    .catch(function (err) {
                    return Observable.of(getEntityAction(entityName).getLoadErrorAction(err.data));
                });
            }
            return Observable.of({ type: 'invalid action' });
        });
        this.addEntities = this._actions$
            .filter(function (action) { return action.type.match(/^.*\/add$/) !== null; })
            .flatMap(function (action) {
            var entityName = extractEntityName(/^(.*)\/add$/, action.type);
            if (entityName !== null) {
                return _this._entityService
                    .addEntity(entityName, action.payload)
                    .map(function (entity) { return getEntityAction(entityName).getAddSuccessAction(entity); })
                    .catch(function (err) {
                    return Observable.of(getEntityAction(entityName).getAddErrorAction(err.data));
                });
            }
            return Observable.of({ type: 'invalid action' });
        });
        this.editEntity = this._actions$
            .filter(function (action) { return action.type.match(/^.*\/edit$/) !== null; })
            .flatMap(function (action) {
            var entityName = extractEntityName(/^(.*)\/edit$/, action.type);
            if (entityName !== null) {
                return _this._entityService
                    .editEntity(entityName, action.payload)
                    .map(function (entity) { return getEntityAction(entityName).getEditSuccessAction(entity); })
                    .catch(function (err) {
                    return Observable.of(getEntityAction(entityName).getEditErrorAction(err.data));
                });
            }
            return Observable.empty();
        });
        this.deleteEntity = this._actions$
            .filter(function (action) { return action.type.match(/^.*\/delete$/) !== null; })
            .flatMap(function (action) {
            var entityName = extractEntityName(/^(.*)\/delete$/, action.type);
            if (entityName !== null) {
                return _this._entityService
                    .deleteEntity(entityName, action.payload)
                    .map(function (entity) { return getEntityAction(entityName).getDeleteSuccessAction(entity); })
                    .catch(function (err) {
                    return Observable.of(getEntityAction(entityName).getDeleteErrorAction(err.data));
                });
            }
            return Observable.empty();
        });
    }
    EntityEffects.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    EntityEffects.ctorParameters = function () { return [
        { type: Actions, },
        { type: EntityService, },
    ]; };
    EntityEffects.propDecorators = {
        'loadEntities': [{ type: Effect },],
        'addEntities': [{ type: Effect },],
        'editEntity': [{ type: Effect },],
        'deleteEntity': [{ type: Effect },],
    };
    return EntityEffects;
}());
export { EntityEffects };
//# sourceMappingURL=effects.js.map